@@ -2,6 +2,7 @@ mod use_async;
 mod use_before_unload;
 mod use_click_away;
 mod use_counter;
+mod use_default;
 mod use_drag;
 mod use_drop;
 mod use_effect_once;
@@ -25,6 +26,7 @@ mod use_previous;
 mod use_queue;
 mod use_raf;
 mod use_raf_state;
+mod use_renders_count;
 mod use_scroll;
 mod use_scrolling;
 mod use_search_param;
@@ -46,6 +48,7 @@ pub use use_async::*;
 pub use use_before_unload::*;
 pub use use_click_away::*;
 pub use use_counter::*;
+pub use use_default::*;
 pub use use_drag::*;
 pub use use_drop::*;
 pub use use_effect_once::*;
@@ -69,6 +72,7 @@ pub use use_previous::*;
 pub use use_queue::*;
 pub use use_raf::*;
 pub use use_raf_state::*;
+pub use use_renders_count::*;
 pub use use_scroll::*;
 pub use use_scrolling::*;
 pub use use_search_param::*;
